#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_FAST_FREXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_FAST_FREXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/fast_frexp.hpp>

#endif
